# pythonPakaging
pythonPackaging

## How to use this

```python
from Perceptron.perceptron import Perceptron

# get x and y and then use below commands
model=Perceptron(eta=ETA, epochs=EPOCHS)
model.fit(X, y)
```

## Reference - 
[official python docs](https://packaging.python.org/en/latest/tutorials/packaging-projects/)

[github docs for github actions](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registeries)